=== modified file 'docs/testing/randgen.rst'
--- docs/testing/randgen.rst	2011-02-24 23:19:35 +0000
+++ docs/testing/randgen.rst	2011-03-02 09:42:13 +0000
@@ -70,7 +70,7 @@
     command = ./gentest.pl --gendata=conf/drizzle/drizzle.zz --grammar=conf/drizzle/optimizer_subquery_drizzle.yy --queries=10 --threads=1
 
     [test_servers]
-    servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+    servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
 
 Running tests
 =========================

=== modified file 'plugin/innobase/docs/index.rst'
--- plugin/innobase/docs/index.rst	2011-03-01 12:37:54 +0000
+++ plugin/innobase/docs/index.rst	2011-03-02 09:42:13 +0000
@@ -58,6 +58,6 @@
 
 .. program:: drizzled
 
-.. option::  --innodb.replication-log=true
+.. option::  --innodb.replication-log
 
 It is not enabled by default.

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-02-22 06:09:35 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-03-02 09:37:25 +0000
@@ -9257,7 +9257,7 @@
           po::value<bool>(&strict_mode)->default_value(false)->zero_tokens(),
           "Use strict mode when evaluating create options.");
   context("replication-log",
-          po::value<bool>(&innobase_use_replication_log)->default_value(false),
+          po::value<bool>(&innobase_use_replication_log)->default_value(false)->zero_tokens(),
           _("Enable internal replication log."));
   context("lock-wait-timeout",
           po::value<lock_wait_constraint>(&lock_wait_timeout)->default_value(50),

=== modified file 'plugin/innobase/tests/t/innodb_replication_log-master.opt'
--- plugin/innobase/tests/t/innodb_replication_log-master.opt	2011-02-04 10:54:23 +0000
+++ plugin/innobase/tests/t/innodb_replication_log-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---innodb.replication-log=1 --transaction-message-threshold=131072
+--innodb.replication-log --transaction-message-threshold=131072

=== modified file 'plugin/slave/docs/index.rst'
--- plugin/slave/docs/index.rst	2011-03-01 12:37:54 +0000
+++ plugin/slave/docs/index.rst	2011-03-02 18:47:07 +0000
@@ -22,7 +22,12 @@
 
 .. option:: --slave.config-file=arg
 
-   Path to the replication slave configuration file.
+   Path to the replication slave configuration file. By default, the
+   plugin will look for a file named `slave.cfg` in the `etc` directory
+   of the Drizzle installation. If you want to specify a different path or
+   configuration file name, it is best to specify a full path to the
+   file. The relative path used by plugins is within the :option:`--datadir`
+   directory, so a full path is recommended.
 
 The options below are read from the configuration file.
 
@@ -52,6 +57,16 @@
    The number of seconds to wait between reconnect attempts when the master
    server becomes unreachable. Default is 30.
 
+.. confval:: io-thread-sleep
+
+   The number of seconds the IO (producer) thread sleeps between queries to the
+   master for more replication events. Default is 5.
+
+.. confval:: applier-thread-sleep
+
+   The number of seconds the applier (consumer) thread sleeps between applying
+   replication events from the local queue. Default is 5.
+
 Implementation Details
 ----------------------
 
@@ -64,7 +79,7 @@
 The producer thread (or I/O thread) is in charge of connecting to the master
 server and pulling down replication events from the master's transaction
 log and storing them locally in the slave queue. It is required that the
-master use the InnoDB replication log (:option:`--innodb.replication-log <drizzled --innodb.replication-log>` = true).
+master use the InnoDB replication log (:option:`--innodb.replication-log <drizzled --innodb.replication-log>`).
 
 The consumer thread (or applier thread) reads the replication events from
 the local slave queue, applies them locally, and then deletes successfully

=== modified file 'plugin/slave/replication_slave.cc'
--- plugin/slave/replication_slave.cc	2011-02-28 21:17:20 +0000
+++ plugin/slave/replication_slave.cc	2011-03-02 16:32:36 +0000
@@ -66,6 +66,14 @@
     ("applier-thread-sleep", po::value<uint32_t>()->default_value(5));
 
   ifstream cf_stream(_config_file.c_str());
+
+  if (not cf_stream.is_open())
+  {
+    _error= "Unable to open file ";
+    _error.append(_config_file);
+    return false;
+  }
+
   po::store(drizzled::program_options::parse_config_file(cf_stream, slave_options), vm);
 
   po::notify(vm);

=== modified file 'plugin/transaction_log/tests/t/alter-master.opt'
--- plugin/transaction_log/tests/t/alter-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/alter-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/auto_commit-master.opt'
--- plugin/transaction_log/tests/t/auto_commit-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/auto_commit-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/blob-master.opt'
--- plugin/transaction_log/tests/t/blob-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/blob-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/create_select-master.opt'
--- plugin/transaction_log/tests/t/create_select-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/create_select-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/create_table-master.opt'
--- plugin/transaction_log/tests/t/create_table-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/create_table-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/delete-master.opt'
--- plugin/transaction_log/tests/t/delete-master.opt	2010-12-02 00:48:51 +0000
+++ plugin/transaction_log/tests/t/delete-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log

=== modified file 'plugin/transaction_log/tests/t/insert-master.opt'
--- plugin/transaction_log/tests/t/insert-master.opt	2010-12-01 03:28:24 +0000
+++ plugin/transaction_log/tests/t/insert-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log

=== modified file 'plugin/transaction_log/tests/t/insert_multi-master.opt'
--- plugin/transaction_log/tests/t/insert_multi-master.opt	2010-12-02 00:48:51 +0000
+++ plugin/transaction_log/tests/t/insert_multi-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log

=== modified file 'plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt'
--- plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/insert_select-master.opt'
--- plugin/transaction_log/tests/t/insert_select-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/insert_select-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/multi_column_primary_key-master.opt'
--- plugin/transaction_log/tests/t/multi_column_primary_key-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/multi_column_primary_key-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/multi_table-master.opt'
--- plugin/transaction_log/tests/t/multi_table-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/multi_table-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/no_modification-master.opt'
--- plugin/transaction_log/tests/t/no_modification-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/no_modification-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/no_primary_key-master.opt'
--- plugin/transaction_log/tests/t/no_primary_key-master.opt	2010-12-02 00:48:51 +0000
+++ plugin/transaction_log/tests/t/no_primary_key-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log

=== modified file 'plugin/transaction_log/tests/t/null_values-master.opt'
--- plugin/transaction_log/tests/t/null_values-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/null_values-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/rand-master.opt'
--- plugin/transaction_log/tests/t/rand-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/rand-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/rename-master.opt'
--- plugin/transaction_log/tests/t/rename-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/rename-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/replace-master.opt'
--- plugin/transaction_log/tests/t/replace-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/replace-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/rollback-master.opt'
--- plugin/transaction_log/tests/t/rollback-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/rollback-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/schema-master.opt'
--- plugin/transaction_log/tests/t/schema-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/schema-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/select_for_update-master.opt'
--- plugin/transaction_log/tests/t/select_for_update-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/select_for_update-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true  --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log  --transaction-message-threshold=131072

=== modified file 'plugin/transaction_log/tests/t/update-master.opt'
--- plugin/transaction_log/tests/t/update-master.opt	2011-02-07 13:29:23 +0000
+++ plugin/transaction_log/tests/t/update-master.opt	2011-03-02 09:37:25 +0000
@@ -1,1 +1,1 @@
---transaction-log.enable --scheduler=multi_thread --innodb.replication-log=true --transaction-message-threshold=131072
+--transaction-log.enable --scheduler=multi_thread --innodb.replication-log --transaction-message-threshold=131072

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread1.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread1.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread1.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent1.yy --Reporter=DrizzleInnoTrxLog  --queries=100 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread1_mix.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread1_mix.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread1_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent1.yy --Reporter=DrizzleInnoTrxLog  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread2.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread2.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread2.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent2.yy --Reporter=DrizzleInnoTrxLog  --queries=75 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread2_mix.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread2_mix.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread2_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent2.yy --Reporter=DrizzleInnoTrxLog  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread3.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread3.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread3.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleInnoTrxLog  --queries=75 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/multi_thread3_mix.cnf'
--- tests/randgen_tests/innodb_trx_log/multi_thread3_mix.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/multi_thread3_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleInnoTrxLog  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/single_thread3.cnf'
--- tests/randgen_tests/innodb_trx_log/single_thread3.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/single_thread3.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleInnoTrxLog  --queries=100 --threads=1
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/innodb_trx_log/trx_ordering.cnf'
--- tests/randgen_tests/innodb_trx_log/trx_ordering.cnf	2011-02-28 23:50:04 +0000
+++ tests/randgen_tests/innodb_trx_log/trx_ordering.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_ordering.zz --grammar=conf/drizzle/translog_ordering.yy --Reporter=DrizzleInnoTrxLog --threads=5  --queries=75
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[]]
+servers = [[--innodb.replication-log],[]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread1.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread1.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread1.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent1.yy --Reporter=DrizzleSlavePlugin  --queries=100 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread1_mix.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread1_mix.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread1_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent1.yy --Reporter=DrizzleSlavePlugin  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread2.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread2.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread2.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent2.yy --Reporter=DrizzleSlavePlugin  --queries=75 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread2_mix.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread2_mix.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread2_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent2.yy --Reporter=DrizzleSlavePlugin  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread3.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread3.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread3.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleSlavePlugin  --queries=250 --threads=3
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/multi_thread3_mix.cnf'
--- tests/randgen_tests/slave_plugin/multi_thread3_mix.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/multi_thread3_mix.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleSlavePlugin  --queries=50 --threads=3 --seed=time
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/single_thread3.cnf'
--- tests/randgen_tests/slave_plugin/single_thread3.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/single_thread3.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_drizzle.zz --grammar=conf/drizzle/translog_concurrent3.yy --Reporter=DrizzleSlavePlugin  --queries=100 --threads=1
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

=== modified file 'tests/randgen_tests/slave_plugin/trx_ordering.cnf'
--- tests/randgen_tests/slave_plugin/trx_ordering.cnf	2011-03-01 01:42:41 +0000
+++ tests/randgen_tests/slave_plugin/trx_ordering.cnf	2011-03-02 09:42:13 +0000
@@ -5,4 +5,4 @@
 command = ./gentest.pl --gendata=conf/drizzle/translog_ordering.zz --grammar=conf/drizzle/translog_ordering.yy --Reporter=DrizzleSlavePlugin --threads=5  --queries=75
 
 [test_servers]
-servers = [[--innodb.replication-log=true],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]
+servers = [[--innodb.replication-log],[--plugin-add=slave --slave.config-file=$MASTER_SERVER_SLAVE_CONFIG]]

